You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [25/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBindingOptions.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBindingOptions.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBindingOptions.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBindingOptions.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.EagerLoad;
-import org.apache.tapestry.ioc.annotation.Scope;
-import org.apache.tapestry.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.annotations.EagerLoad;
+import org.apache.tapestry5.ioc.annotations.Scope;
+import org.apache.tapestry5.ioc.def.ServiceDef;
 
 import java.lang.annotation.Annotation;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBuilderResources.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBuilderResources.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceLifecycle.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceLifecycle.java Tue May 20 11:51:35 2008
@@ -1,18 +1,18 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
  * Allows certain types of lifecycles to control exactly how services are instantiated.
@@ -20,14 +20,12 @@
 public interface ServiceLifecycle
 {
     /**
-     * Returns the same creator, or a new one, that encapsulates the creation of the core service
-     * implementation.
+     * Returns the same creator, or a new one, that encapsulates the creation of the core service implementation.
      *
-     * @param resources source of information about the service to be created, and source of additional
-     *                  services or other resources that may be needed when constructing the core service
-     *                  implementation
-     * @param creator   object capable of creating the service implementation on demand. This is a wrapper
-     *                  around the service's builder method.
+     * @param resources source of information about the service to be created, and source of additional services or
+     *                  other resources that may be needed when constructing the core service implementation
+     * @param creator   object capable of creating the service implementation on demand. This is a wrapper around the
+     *                  service's builder method.
      * @return the service or equivalent service proxy
      */
     Object createService(ServiceResources resources, ObjectCreator creator);

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceResources.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceResources.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/EagerLoad.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/EagerLoad.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
-import org.apache.tapestry.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.ServiceBinder;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Marker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Marker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Match.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Match.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Order.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Order.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Order.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Order.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;
@@ -24,7 +24,7 @@
  * Used with a service decorator method to control the order in which decorations occur. Identifies other decorators
  * which should occur before the annotated decorator.
  *
- * @see org.apache.tapestry.ioc.def.DecoratorDef
+ * @see org.apache.tapestry5.ioc.def.DecoratorDef
  */
 @Target(METHOD)
 @Retention(RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Scope.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Scope.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Scope.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Scope.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
-import org.apache.tapestry.ioc.ServiceBinder;
-import org.apache.tapestry.ioc.ServiceLifecycle;
-import org.apache.tapestry.ioc.services.ServiceLifecycleSource;
+import org.apache.tapestry5.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.ServiceLifecycle;
+import org.apache.tapestry5.ioc.services.ServiceLifecycleSource;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/SubModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/SubModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/SubModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/SubModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.TYPE;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ContributionDef.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ContributionDef.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ContributionDef.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ContributionDef.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.def;
+package org.apache.tapestry5.ioc.def;
 
-import org.apache.tapestry.ioc.*;
+import org.apache.tapestry5.ioc.*;
 
 /**
  * Contribution to a service configuration.
  * <p/>
- * The toString() method of the ContributionDef will be used for some exception reporting and should
- * clearly identify where the contribution comes from; the normal behavior is to identify the class
- * and method of the contribution method.
+ * The toString() method of the ContributionDef will be used for some exception reporting and should clearly identify
+ * where the contribution comes from; the normal behavior is to identify the class and method of the contribution
+ * method.
  */
 public interface ContributionDef
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/DecoratorDef.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/DecoratorDef.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/DecoratorDef.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/DecoratorDef.java Tue May 20 11:51:35 2008
@@ -12,31 +12,29 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.def;
+package org.apache.tapestry5.ioc.def;
 
-import org.apache.tapestry.ioc.ModuleBuilderSource;
-import org.apache.tapestry.ioc.ServiceDecorator;
-import org.apache.tapestry.ioc.ServiceResources;
+import org.apache.tapestry5.ioc.ModuleBuilderSource;
+import org.apache.tapestry5.ioc.ServiceDecorator;
+import org.apache.tapestry5.ioc.ServiceResources;
 
 /**
  * Definition of a service decorator, which (by default) is derived from a service decorator method.
  * <p/>
- * A note on decorator scheduling. The scheduling is based on the desired order of <em>behavior</em>.
- * Thus, if logging should occur before security checks, and security checks should occur before
- * transaction management, then the desired decorator order is Logging, Security, Transactions. This
- * might be specified as having Security occur after Logging, and Transactions occur after Security.
- * It might also be specified by having Logging ordered "before:*", and Transactions ordered
- * "after:*" with no specified scheduling for Security.
+ * A note on decorator scheduling. The scheduling is based on the desired order of <em>behavior</em>. Thus, if logging
+ * should occur before security checks, and security checks should occur before transaction management, then the desired
+ * decorator order is Logging, Security, Transactions. This might be specified as having Security occur after Logging,
+ * and Transactions occur after Security. It might also be specified by having Logging ordered "before:*", and
+ * Transactions ordered "after:*" with no specified scheduling for Security.
  * <p/>
- * Once this order is established, decorators are <em>applied</em> in reverse order. Each
- * decorator's job is to create an <em>interceptor</em> for the service, that delegates to the
- * next implementation. This implies that the decorators are executed last to first. In the above
- * example, the core service implementation would be passed to the Transaction decorator, resulting
- * in the Transaction interceptor. The Transaction interceptor would be passed to the Security
- * decorator, resulting in the Security interceptor. The Security interceptor would be passed to the
- * Logging decorator, resulting in the Logging interceptor. Thus at runtime, the Logging interceptor
- * will execute first, then delegate to the Security interceptor, which would delegate to the
- * Transaction interceptor, which would finally delegate to the core service implementation.
+ * Once this order is established, decorators are <em>applied</em> in reverse order. Each decorator's job is to create
+ * an <em>interceptor</em> for the service, that delegates to the next implementation. This implies that the decorators
+ * are executed last to first. In the above example, the core service implementation would be passed to the Transaction
+ * decorator, resulting in the Transaction interceptor. The Transaction interceptor would be passed to the Security
+ * decorator, resulting in the Security interceptor. The Security interceptor would be passed to the Logging decorator,
+ * resulting in the Logging interceptor. Thus at runtime, the Logging interceptor will execute first, then delegate to
+ * the Security interceptor, which would delegate to the Transaction interceptor, which would finally delegate to the
+ * core service implementation.
  */
 public interface DecoratorDef
 {
@@ -46,32 +44,31 @@
     String getDecoratorId();
 
     /**
-     * Returns zero or more ordering constraint strings, used to order the decorated relative to the
-     * other decorators.
+     * Returns zero or more ordering constraint strings, used to order the decorated relative to the other decorators.
      */
 
     String[] getConstraints();
 
     /**
-     * Creates an object that can perform the decoration (in the default case, by invoking the
-     * decorator method on the module builder instance.
+     * Creates an object that can perform the decoration (in the default case, by invoking the decorator method on the
+     * module builder instance.
      *
-     * @param moduleBuilderSource the module builder instance associated with the module containing the decorator
-     *                            (not necessarily the module containing the service being decorated)
-     * @param resources           the resources visible <em>to the decorator</em> (which may be in a different
-     *                            module than the service being decorated). Other resource properties (serviceId,
+     * @param moduleBuilderSource the module builder instance associated with the module containing the decorator (not
+     *                            necessarily the module containing the service being decorated)
+     * @param resources           the resources visible <em>to the decorator</em> (which may be in a different module
+     *                            than the service being decorated). Other resource properties (serviceId,
      *                            serviceInterface, log, etc.) are for the service being decorated.
      */
     ServiceDecorator createDecorator(ModuleBuilderSource moduleBuilderSource,
                                      ServiceResources resources);
 
     /**
-     * Used to determine which services may be decorated by this decorator. When decorating a
-     * service, first the decorators that target the service are identified, then ordering occurs,
-     * then the {@link ServiceDecorator}s are invoked.
+     * Used to determine which services may be decorated by this decorator. When decorating a service, first the
+     * decorators that target the service are identified, then ordering occurs, then the {@link ServiceDecorator}s are
+     * invoked.
      *
      * @param serviceDef
      * @return true if the decorator applies to the service
      */
     boolean matches(ServiceDef serviceDef);
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ModuleDef.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ModuleDef.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ModuleDef.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ModuleDef.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.def;
+package org.apache.tapestry5.ioc.def;
 
 import org.slf4j.Logger;
 
 import java.util.Set;
 
 /**
- * Defines the contents of a module. In the default case, this is information about the services
- * provided by the module builder class.
+ * Defines the contents of a module. In the default case, this is information about the services provided by the module
+ * builder class.
  */
 public interface ModuleDef
 {
@@ -48,15 +48,13 @@
     Set<ContributionDef> getContributionDefs();
 
     /**
-     * Returns the class that will be instantiated. Annotated instance methods of this class are
-     * invoked to build services, to decorate/intercept services, and make contributions to other
-     * services.
+     * Returns the class that will be instantiated. Annotated instance methods of this class are invoked to build
+     * services, to decorate/intercept services, and make contributions to other services.
      */
     Class getBuilderClass();
 
     /**
-     * Returns the name used to create a {@link Logger} instance. This is typically the builder class
-     * name.
+     * Returns the name used to create a {@link Logger} instance. This is typically the builder class name.
      */
     String getLoggerName();
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ServiceDef.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ServiceDef.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/AbstractServiceCreator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/AbstractServiceCreator.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import org.apache.tapestry.ioc.ObjectLocator;
-import org.apache.tapestry.ioc.ServiceBuilderResources;
-import org.apache.tapestry.ioc.ServiceResources;
-import static org.apache.tapestry.ioc.internal.ConfigurationType.*;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import org.apache.tapestry5.ioc.ObjectLocator;
+import org.apache.tapestry5.ioc.ServiceBuilderResources;
+import org.apache.tapestry5.ioc.ServiceResources;
+import static org.apache.tapestry5.ioc.internal.ConfigurationType.*;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
 import org.slf4j.Logger;
 
 import java.lang.reflect.ParameterizedType;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConfigurationType.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConfigurationType.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConfigurationType.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConfigurationType.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 /**
  * Defines the three types of configurations a service may request.
@@ -21,15 +21,15 @@
 {
 
     /**
-     * @see org.apache.tapestry.ioc.Configuration
+     * @see org.apache.tapestry5.ioc.Configuration
      */
     UNORDERED,
     /**
-     * @see org.apache.tapestry.ioc.OrderedConfiguration
+     * @see org.apache.tapestry5.ioc.OrderedConfiguration
      */
     ORDERED,
     /**
-     * @see org.apache.tapestry.ioc.MappedConfiguration
+     * @see org.apache.tapestry5.ioc.MappedConfiguration
      */
     MAPPED
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConstructorServiceCreator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConstructorServiceCreator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConstructorServiceCreator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ConstructorServiceCreator.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ServiceBuilderResources;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.ServiceBuilderResources;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ContributionDefImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ContributionDefImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ContributionDefImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ContributionDefImpl.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.ClassFactory;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DecoratorDefImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DecoratorDefImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DecoratorDefImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DecoratorDefImpl.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.IdMatcher;
-import org.apache.tapestry.ioc.ModuleBuilderSource;
-import org.apache.tapestry.ioc.ServiceDecorator;
-import org.apache.tapestry.ioc.ServiceResources;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import static org.apache.tapestry.ioc.internal.util.Defense.notBlank;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.IdMatcher;
+import org.apache.tapestry5.ioc.ModuleBuilderSource;
+import org.apache.tapestry5.ioc.ServiceDecorator;
+import org.apache.tapestry5.ioc.ServiceResources;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notBlank;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.ClassFactory;
 
 import java.lang.reflect.Method;
 import java.util.List;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImpl.java Tue May 20 11:51:35 2008
@@ -12,20 +12,20 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.annotation.*;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import static org.apache.tapestry.ioc.internal.ConfigurationType.*;
-import static org.apache.tapestry.ioc.internal.IOCMessages.*;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.*;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.annotations.*;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import static org.apache.tapestry5.ioc.internal.ConfigurationType.*;
+import static org.apache.tapestry5.ioc.internal.IOCMessages.*;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.*;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.ClassFactory;
 import org.slf4j.Logger;
 
 import java.lang.reflect.InvocationTargetException;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/EagerLoadServiceProxy.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/EagerLoadServiceProxy.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcher.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcher.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import static org.apache.tapestry.ioc.internal.MatchType.*;
+import static org.apache.tapestry5.ioc.internal.MatchType.*;
 
 public class GlobPatternMatcher
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCInternalTestCase.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCInternalTestCase.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCInternalTestCase.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCInternalTestCase.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.services.ClassFactory;
-import org.apache.tapestry.ioc.test.IOCTestCase;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.test.IOCTestCase;
 import static org.easymock.EasyMock.isA;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.AfterSuite;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCMessages.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCMessages.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCMessages.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IOCMessages.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import static org.apache.tapestry.ioc.internal.util.InternalUtils.asString;
-import org.apache.tapestry.ioc.internal.util.MessagesImpl;
-import org.apache.tapestry.ioc.services.ClassFabUtils;
-import static org.apache.tapestry.ioc.services.ClassFabUtils.toJavaClassName;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import static org.apache.tapestry5.ioc.internal.util.InternalUtils.asString;
+import org.apache.tapestry5.ioc.internal.util.MessagesImpl;
+import org.apache.tapestry5.ioc.services.ClassFabUtils;
+import static org.apache.tapestry5.ioc.services.ClassFabUtils.toJavaClassName;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IdMatcherImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IdMatcherImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IdMatcherImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/IdMatcherImpl.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.IdMatcher;
+import org.apache.tapestry5.ioc.IdMatcher;
 
 /**
  * A wrapper around a {@link GlobPatternMatcher} used to glob-match service ids.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LoggerSourceImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LoggerSourceImpl.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.LoggerSource;
+import org.apache.tapestry5.ioc.LoggerSource;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * Simple wrapper around SLF4J's LoggerFactory. The concept here is that Log implementations could
- * be provided that promote warnings or errors upto thrown exceptions, for people who like their IOC
- * container extra finicky. In addition, the extra layer makes things a lot easier to mock.
+ * Simple wrapper around SLF4J's LoggerFactory. The concept here is that Log implementations could be provided that
+ * promote warnings or errors upto thrown exceptions, for people who like their IOC container extra finicky. In
+ * addition, the extra layer makes things a lot easier to mock.
  */
 public class LoggerSourceImpl implements LoggerSource
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/MatchType.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/MatchType.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/MatchType.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/MatchType.java Tue May 20 11:51:35 2008
@@ -15,9 +15,9 @@
 /**
  *
  */
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 enum MatchType
 {
     EXACT, PREFIX, SUFFIX, INFIX, ANY
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/Module.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/Module.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ModuleImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ModuleImpl.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.internal.services.JustInTimeObjectCreator;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.*;
-import static org.apache.tapestry.ioc.internal.util.Defense.notBlank;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.*;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.internal.services.JustInTimeObjectCreator;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.*;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notBlank;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.*;
 import org.slf4j.Logger;
 
 import java.io.ObjectStreamException;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/NullAnnotationProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/NullAnnotationProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/NullAnnotationProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/NullAnnotationProvider.java Tue May 20 11:51:35 2008
@@ -12,15 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.AnnotationProvider;
 
 import java.lang.annotation.Annotation;
 
 /**
- * A null implementation of {@link AnnotationProvider}, used when there is not appropriate source
- * of annotations.
+ * A null implementation of {@link AnnotationProvider}, used when there is not appropriate source of annotations.
  */
 public class NullAnnotationProvider implements AnnotationProvider
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectCreatorSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectCreatorSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectCreatorSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectCreatorSource.java Tue May 20 11:51:35 2008
@@ -12,22 +12,20 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import org.apache.tapestry.ioc.ServiceBuilderResources;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import org.apache.tapestry5.ioc.ServiceBuilderResources;
 
 /**
- * An object which can, when passed a {@link ServiceBuilderResources}, create a corresponding
- * {@link ObjectCreator}. A secondary responsibility is to provide a description of the creator,
- * which is usually based on the name of the method or constructor to be invoked, and is ultimately
- * used in some debugging or error output.
+ * An object which can, when passed a {@link ServiceBuilderResources}, create a corresponding {@link ObjectCreator}. A
+ * secondary responsibility is to provide a description of the creator, which is usually based on the name of the method
+ * or constructor to be invoked, and is ultimately used in some debugging or error output.
  */
 public interface ObjectCreatorSource
 {
     /**
-     * Provides an ObjectCreator that can be used to ultimately instantiate the core service
-     * implementation.
+     * Provides an ObjectCreator that can be used to ultimately instantiate the core service implementation.
      */
     ObjectCreator constructCreator(ServiceBuilderResources resources);
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectLocatorImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectLocatorImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectLocatorImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ObjectLocatorImpl.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
-import org.apache.tapestry.ioc.ObjectLocator;
+import org.apache.tapestry5.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.ObjectLocator;
 
 /**
  * Base service locator class used when only the module is known (i.e., when instantiating a module builder class).

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/OrIdMatcher.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/OrIdMatcher.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/OrIdMatcher.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/OrIdMatcher.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.IdMatcher;
+import org.apache.tapestry5.ioc.IdMatcher;
 
 import java.util.Collection;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RecursiveServiceCreationCheckWrapper.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RecursiveServiceCreationCheckWrapper.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RecursiveServiceCreationCheckWrapper.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RecursiveServiceCreationCheckWrapper.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import org.apache.tapestry.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import org.apache.tapestry5.ioc.def.ServiceDef;
 import org.slf4j.Logger;
 
 /**
- * Decorator for {@link org.apache.tapestry.ioc.ObjectCreator} that ensures the service is only created once. This
+ * Decorator for {@link org.apache.tapestry5.ioc.ObjectCreator} that ensures the service is only created once. This
  * detects a situation where the service builder for a service directly or indirectly invokes methods on the service
  * itself. This would show up as a second call up the ServiceCreator stack injected into the proxy, potentially leading
  * to endless recursion. We try to identify that recursion and produce a useable exception report.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryWrapper.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryWrapper.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
-import org.apache.tapestry.ioc.ObjectLocator;
-import org.apache.tapestry.ioc.Registry;
+import org.apache.tapestry5.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.ObjectLocator;
+import org.apache.tapestry5.ioc.Registry;
 
 /**
  * A wrapper around {@link InternalRegistry} that exists to expand symbols in a service id before invoking {@link
@@ -73,4 +73,4 @@
         return registry.proxy(interfaceClass, implementationClass);
     }
 
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/SerializationSupport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/SerializationSupport.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/SerializationSupport.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/SerializationSupport.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -78,4 +78,4 @@
         return new ServiceProxyToken(serviceId);
     }
 
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTracker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTracker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTracker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTracker.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.services.ServiceActivityScoreboard;
-import org.apache.tapestry.ioc.services.Status;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.services.ServiceActivityScoreboard;
+import org.apache.tapestry5.ioc.services.Status;
 
 /**
  * Used to update the status of services defined by the {@link ServiceActivityScoreboard}.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTrackerImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTrackerImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTrackerImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceActivityTrackerImpl.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.services.ServiceActivity;
-import org.apache.tapestry.ioc.services.ServiceActivityScoreboard;
-import org.apache.tapestry.ioc.services.Status;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.services.ServiceActivity;
+import org.apache.tapestry5.ioc.services.ServiceActivityScoreboard;
+import org.apache.tapestry5.ioc.services.Status;
 
 import java.util.List;
 import java.util.Map;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBinderImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBinderImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBinderImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBinderImpl.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.annotation.EagerLoad;
-import org.apache.tapestry.ioc.annotation.Marker;
-import org.apache.tapestry.ioc.annotation.Scope;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import static org.apache.tapestry.ioc.internal.util.Defense.notBlank;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.internal.util.OneShotLock;
-import org.apache.tapestry.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.annotations.EagerLoad;
+import org.apache.tapestry5.ioc.annotations.Marker;
+import org.apache.tapestry5.ioc.annotations.Scope;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notBlank;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.OneShotLock;
+import org.apache.tapestry5.ioc.services.ClassFactory;
 
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBuilderMethodInvoker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBuilderMethodInvoker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceDecoratorImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceDecoratorImpl.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ModuleBuilderSource;
-import org.apache.tapestry.ioc.ServiceDecorator;
-import org.apache.tapestry.ioc.ServiceResources;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newMap;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.ModuleBuilderSource;
+import org.apache.tapestry5.ioc.ServiceDecorator;
+import org.apache.tapestry5.ioc.ServiceResources;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newMap;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.ClassFactory;
 import org.slf4j.Logger;
 
 import java.lang.reflect.InvocationTargetException;
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBuilderResources.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBuilderResources.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 
 /**
  * Extends {@link org.apache.tapestry.ioc.ServiceResources} with additional methods needed only by
  * the service builder method, related to accessing a service's configuration. Services may have a
  * <em>single</em> configuration in one of three flavors: unordered, ordered or mapped.
  */
 public interface ServiceBuilderResources extends ServiceResources, ModuleBuilderSource
 {
@@ -12,16 +12,16 @@
 
 /**
- * Extends {@link org.apache.tapestry.ioc.ServiceResources} with additional methods needed only by
- * the service builder method, related to accessing a service's configuration. Services may have a
- * <em>single</em> configuration in one of three flavors: unordered, ordered or mapped.
+ * Extends {@link org.apache.tapestry5.ioc.ServiceResources} with additional methods needed only by the service builder
+ * method, related to accessing a service's configuration. Services may have a <em>single</em> configuration in one of
+ * three flavors: unordered, ordered or mapped.
  */
 public interface ServiceBuilderResources extends ServiceResources, ModuleBuilderSource

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceDecorator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceDecorator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceDecorator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceDecorator.java Tue May 20 11:51:35 2008
@@ -1,33 +1,31 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
  * A service decorator is derived from a {@link org.apache.tapestry.ioc.def.DecoratorDef} and is
  * responsible for building an interceptor around an existing implementation (called the
  * "delegate").
  */
 public interface ServiceDecorator
 {
     /**
-     * Creates a new interceptor object implementing the same service interface as the delegate
-     * object.
+     * Creates a new interceptor object implementing the same service interface as the delegate object.
      *
      * @param delegate an existing object implementing the service interface.
-     * @return a new object implementing the same service interface, or delegate or null if the
-     *         decorator chooses not to create a new interceptor.
+     * @return a new object implementing the same service interface, or delegate or null if the decorator chooses not to
+     *         create a new interceptor.
      */
     public Object createInterceptor(Object delegate);
 }
@@ -1,33 +1,31 @@
 
 /**
- * A service decorator is derived from a {@link org.apache.tapestry.ioc.def.DecoratorDef} and is
- * responsible for building an interceptor around an existing implementation (called the
- * "delegate").
+ * A service decorator is derived from a {@link org.apache.tapestry5.ioc.def.DecoratorDef} and is responsible for
+ * building an interceptor around an existing implementation (called the "delegate").
  */
 public interface ServiceDecorator

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceLifecycle.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceLifecycle.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceResources.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceResources.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import org.slf4j.Logger;
 
 /**
  * Contains resources that may be provided to a service when it initializes, which includes other
  * services defined in the registry. ServiceResources provides access to other services (it extends
  * {@link org.apache.tapestry.ioc.ObjectLocator}).
  */
 public interface ServiceResources extends ObjectLocator
 {
@@ -34,10 +34,9 @@
     Class getServiceInterface();
 
     /**
-     * Returns a Logger appropriate for logging messages. This includes debug level messages about
-     * the creation and configuration of the underlying service, as well as debug, warning, or error
-     * level messages from the service itself. Often service interceptors will make use of the
-     * service's logger.
+     * Returns a Logger appropriate for logging messages. This includes debug level messages about the creation and
+     * configuration of the underlying service, as well as debug, warning, or error level messages from the service
+     * itself. Often service interceptors will make use of the service's logger.
      */
     Logger getLogger();
 }
@@ -12,14 +12,14 @@
 
 /**
- * Contains resources that may be provided to a service when it initializes, which includes other
- * services defined in the registry. ServiceResources provides access to other services (it extends
- * {@link org.apache.tapestry.ioc.ObjectLocator}).
+ * Contains resources that may be provided to a service when it initializes, which includes other services defined in
+ * the registry. ServiceResources provides access to other services (it extends {@link
+ * org.apache.tapestry5.ioc.ObjectLocator}).
  */
 public interface ServiceResources extends ObjectLocator

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/EagerLoad.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/EagerLoad.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Marker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Marker.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
-import org.apache.tapestry.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;
@@ -30,7 +30,7 @@
  * <p/>
  * When applied to a module class, this sets the default markers for all services within the module.  Markers are
  * additive, so a Marker annotation on the implementation class and/or specified with {@link
  * org.apache.tapestry.ioc.ServiceBindingOptions#withMarker(Class[])} will accumulate; a service may have any number of
  * markers.  Generally one or two is enough.
  */
 @Target(
@@ -30,7 +30,7 @@
  * When applied to a module class, this sets the default markers for all services within the module.  Markers are
  * additive, so a Marker annotation on the implementation class and/or specified with {@link
- * org.apache.tapestry.ioc.ServiceBindingOptions#withMarker(Class[])} will accumulate; a service may have any number of
+ * org.apache.tapestry5.ioc.ServiceBindingOptions#withMarker(Class[])} will accumulate; a service may have any number of
  * markers.  Generally one or two is enough.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Match.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/annotation/Match.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ServiceDef.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/def/ServiceDef.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.def;
+package org.apache.tapestry5.ioc.def;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import org.apache.tapestry.ioc.ServiceBuilderResources;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import org.apache.tapestry5.ioc.ServiceBuilderResources;
 
 import java.util.Set;
 
@@ -59,7 +59,7 @@
 
     /**
      * Returns the lifecycle defined for the service. This is indicated by adding a {@link
      * org.apache.tapestry.ioc.annotation.Scope} annotation to the service builder method for the service.
      * <p/>
      * Services that are not proxied will ignore their scope; such services are always treated as singletons.
      */
@@ -68,7 +68,7 @@
     /**
      * Returns true if the service should be eagerly loaded at Registry startup.
      *
-     * @see org.apache.tapestry.ioc.annotation.EagerLoad
+     * @see org.apache.tapestry5.ioc.annotations.EagerLoad
      */
     boolean isEagerLoad();
-}
\ No newline at end of file
+}
@@ -59,7 +59,7 @@
     /**
      * Returns the lifecycle defined for the service. This is indicated by adding a {@link
-     * org.apache.tapestry.ioc.annotation.Scope} annotation to the service builder method for the service.
+     * org.apache.tapestry5.ioc.annotations.Scope} annotation to the service builder method for the service.
      * <p/>
      * Services that are not proxied will ignore their scope; such services are always treated as singletons.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/AbstractServiceCreator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/AbstractServiceCreator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/EagerLoadServiceProxy.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/EagerLoadServiceProxy.java Tue May 20 11:51:35 2008
@@ -1,22 +1,22 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.internal;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.internal;
 
 /**
  * Interface implemented by all service proxies. Service proxies are always
  * {@link org.apache.tapestry.ioc.services.RegistryShutdownListener}s, they also can be eager-load
  */
 public interface EagerLoadServiceProxy
 {
@@ -1,22 +1,22 @@
 
 /**
- * Interface implemented by all service proxies. Service proxies are always
- * {@link org.apache.tapestry.ioc.services.RegistryShutdownListener}s, they also can be eager-load
+ * Interface implemented by all service proxies. Service proxies are always {@link
+ * org.apache.tapestry5.ioc.services.RegistryShutdownListener}s, they also can be eager-load
  */
 public interface EagerLoadServiceProxy

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcher.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcher.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilder.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import org.apache.tapestry.ioc.ServiceDecorator;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import org.apache.tapestry5.ioc.ServiceDecorator;
 
 import java.util.Collections;
 import java.util.List;
 
 /**
  * Responsible for constructing the interceptor stack, on demand, by invoking an ordered series of decorators ({@link
  * org.apache.tapestry.ioc.def.DecoratorDef} (which are converted into {@link ServiceDecorator}s).
  */
 public class InterceptorStackBuilder implements ObjectCreator
 {
@@ -12,17 +12,17 @@
 /**
  * Responsible for constructing the interceptor stack, on demand, by invoking an ordered series of decorators ({@link
- * org.apache.tapestry.ioc.def.DecoratorDef} (which are converted into {@link ServiceDecorator}s).
+ * org.apache.tapestry5.ioc.def.DecoratorDef} (which are converted into {@link ServiceDecorator}s).
  */
 public class InterceptorStackBuilder implements ObjectCreator

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InternalRegistry.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InternalRegistry.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InternalRegistry.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/InternalRegistry.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.Registry;
-import org.apache.tapestry.ioc.ServiceDecorator;
-import org.apache.tapestry.ioc.ServiceLifecycle;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.services.ClassFab;
-import org.apache.tapestry.ioc.services.RegistryShutdownHub;
+import org.apache.tapestry5.ioc.Registry;
+import org.apache.tapestry5.ioc.ServiceDecorator;
+import org.apache.tapestry5.ioc.ServiceLifecycle;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.services.ClassFab;
+import org.apache.tapestry5.ioc.services.RegistryShutdownHub;
 import org.slf4j.Logger;
 
 import java.util.Collection;
@@ -41,15 +41,14 @@
     ServiceLifecycle getServiceLifecycle(String scope);
 
     /**
      * Searches for decorators for a particular service. The resulting
      * {@link org.apache.tapestry.ioc.def.DecoratorDef}s are ordered, then converted into
      * {@link ServiceDecorator}s.
      */
     List<ServiceDecorator> findDecoratorsForService(ServiceDef serviceDef);
 
     /**
-     * Builds up an unordered collection by invoking service contributor methods that target the
-     * service (from any module, unless the service is private).
+     * Builds up an unordered collection by invoking service contributor methods that target the service (from any
+     * module, unless the service is private).
      *
      * @param <T>
      * @param serviceDef defines the service for which configuration data is being assembled
@@ -59,10 +58,9 @@
     <T> Collection<T> getUnorderedConfiguration(ServiceDef serviceDef, Class<T> valueType);
 
     /**
-     * Builds up an ordered collection by invoking service contributor methods that target the
-     * service (from any module, unless the service is private). Once all values have been added
-     * (each with an id, and pre/post constraints), the values are ordered, null values dropped, and
-     * the final sorted list is returned.
+     * Builds up an ordered collection by invoking service contributor methods that target the service (from any module,
+     * unless the service is private). Once all values have been added (each with an id, and pre/post constraints), the
+     * values are ordered, null values dropped, and the final sorted list is returned.
      *
      * @param <T>
      * @param serviceDef defines the service for which configuration data is being assembled
@@ -72,10 +70,9 @@
     <T> List<T> getOrderedConfiguration(ServiceDef serviceDef, Class<T> valueType);
 
     /**
-     * Builds up a map of key/value pairs by invoking service contribution methods that tharget the
-     * service (from any module, unless the service is private). Values and keys may not be null.
-     * Invalid values (keys or values that are the wrong type, or duplicate keys) result in warnings
-     * and are ignored.
+     * Builds up a map of key/value pairs by invoking service contribution methods that tharget the service (from any
+     * module, unless the service is private). Values and keys may not be null. Invalid values (keys or values that are
+     * the wrong type, or duplicate keys) result in warnings and are ignored.
      *
      * @param <K,        V>
      * @param serviceDef defines the service for which configuration data is being assembled
@@ -87,16 +84,15 @@
                                             Class<V> valueType);
 
     /**
      * Convieience for creating a new {@link ClassFab} instance using a
      * {@link org.apache.tapestry.ioc.services.ClassFactory}.
      *
      * @param serviceInterface the interface to be implemented by the provided class
      */
     ClassFab newClass(Class serviceInterface);
 
     /**
-     * Given an input string that <em>may</em> contain symbols, returns the string with any and
-     * all symbols fully expanded.
+     * Given an input string that <em>may</em> contain symbols, returns the string with any and all symbols fully
+     * expanded.
      *
      * @param input
      * @return expanded input
@@ -104,8 +100,8 @@
     String expandSymbols(String input);
 
     /**
-     * Returns a logger for the service, which consists of the Module's
-     * {@link Module#getLoggerName() log name} suffixed with a period and the service id.
+     * Returns a logger for the service, which consists of the Module's {@link Module#getLoggerName() log name} suffixed
+     * with a period and the service id.
      *
      * @param serviceId
      * @return the logger for the service
@@ -41,15 +41,14 @@
 
     /**
-     * Searches for decorators for a particular service. The resulting
-     * {@link org.apache.tapestry.ioc.def.DecoratorDef}s are ordered, then converted into
-     * {@link ServiceDecorator}s.
+     * Searches for decorators for a particular service. The resulting {@link org.apache.tapestry5.ioc.def.DecoratorDef}s
+     * are ordered, then converted into {@link ServiceDecorator}s.
      */
     List<ServiceDecorator> findDecoratorsForService(ServiceDef serviceDef);
@@ -87,16 +84,15 @@
 
     /**
-     * Convieience for creating a new {@link ClassFab} instance using a
-     * {@link org.apache.tapestry.ioc.services.ClassFactory}.
+     * Convieience for creating a new {@link ClassFab} instance using a {@link org.apache.tapestry5.ioc.services.ClassFactory}.
      *
      * @param serviceInterface the interface to be implemented by the provided class

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LifecycleWrappedServiceCreator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LifecycleWrappedServiceCreator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LifecycleWrappedServiceCreator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LifecycleWrappedServiceCreator.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import org.apache.tapestry.ioc.ServiceLifecycle;
-import org.apache.tapestry.ioc.ServiceResources;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import org.apache.tapestry5.ioc.ServiceLifecycle;
+import org.apache.tapestry5.ioc.ServiceResources;
 
 /**
  * Wrapper around a lifecycle, a set of resources for a service, and an underlying {@link ObjectCreator} for a service
@@ -43,7 +43,7 @@
     }
 
     /**
      * Passes the resources and the service creator through the {@link org.apache.tapestry.ioc.ServiceLifecycle}.
      */
     public Object createObject()
     {
@@ -43,7 +43,7 @@
 
     /**
-     * Passes the resources and the service creator through the {@link org.apache.tapestry.ioc.ServiceLifecycle}.
+     * Passes the resources and the service creator through the {@link org.apache.tapestry5.ioc.ServiceLifecycle}.
      */
     public Object createObject()

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LoggerSourceImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/LoggerSourceImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/Module.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/Module.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ModuleBuilderSource;
-import org.apache.tapestry.ioc.ServiceDecorator;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.ModuleBuilderSource;
+import org.apache.tapestry5.ioc.ServiceDecorator;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
 
 import java.util.Collection;
 import java.util.List;
@@ -53,7 +53,7 @@
     /**
      * Locates all the decorators that should apply the identified service. This includes visibility rules (private
      * services may only be decorated by decorators in the same module) and other filtering rules. The resulting list is
      * ordered and from the list of {@link org.apache.tapestry.ioc.def.DecoratorDef}s, a list of {@link
      * ServiceDecorator}s is returned.
      *
      * @param serviceId identifies the service to be decorated
@@ -76,7 +76,7 @@
     Set<ContributionDef> getContributorDefsForService(String serviceId);
 
     /**
      * Locates services with the {@link org.apache.tapestry.ioc.annotation.EagerLoad} annotation and generates proxies
      * for them, then adds them to the proxies list for instantiation.
      *
      * @param proxies collection of proxies to which any eager load services in the module should be added
@@ -53,7 +53,7 @@
      * Locates all the decorators that should apply the identified service. This includes visibility rules (private
      * services may only be decorated by decorators in the same module) and other filtering rules. The resulting list is
-     * ordered and from the list of {@link org.apache.tapestry.ioc.def.DecoratorDef}s, a list of {@link
+     * ordered and from the list of {@link org.apache.tapestry5.ioc.def.DecoratorDef}s, a list of {@link
      * ServiceDecorator}s is returned.
      *
@@ -76,7 +76,7 @@
 
     /**
-     * Locates services with the {@link org.apache.tapestry.ioc.annotation.EagerLoad} annotation and generates proxies
+     * Locates services with the {@link org.apache.tapestry5.ioc.annotations.EagerLoad} annotation and generates proxies
      * for them, then adds them to the proxies list for instantiation.
      *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ModuleImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ModuleImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryImpl.java Tue May 20 11:51:35 2008
@@ -12,22 +12,22 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.internal.services.PerthreadManagerImpl;
-import org.apache.tapestry.ioc.internal.services.RegistryShutdownHubImpl;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.*;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.internal.util.OneShotLock;
-import org.apache.tapestry.ioc.internal.util.Orderer;
-import org.apache.tapestry.ioc.services.*;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.internal.services.PerthreadManagerImpl;
+import org.apache.tapestry5.ioc.internal.services.RegistryShutdownHubImpl;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.*;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.OneShotLock;
+import org.apache.tapestry5.ioc.internal.util.Orderer;
+import org.apache.tapestry5.ioc.services.*;
 import org.slf4j.Logger;
 
 import java.lang.reflect.Constructor;
@@ -55,7 +55,7 @@
     }
 
     /**
      * Used to obtain the {@link org.apache.tapestry.ioc.services.ClassFactory} service, which is crucial when creating
      * runtime classes for proxies and the like.
      */
     static final String CLASS_FACTORY_SERVICE_ID = "ClassFactory";
@@ -55,7 +55,7 @@
 
     /**
-     * Used to obtain the {@link org.apache.tapestry.ioc.services.ClassFactory} service, which is crucial when creating
+     * Used to obtain the {@link org.apache.tapestry5.ioc.services.ClassFactory} service, which is crucial when creating
      * runtime classes for proxies and the like.
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryWrapper.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/RegistryWrapper.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBuilderMethodInvoker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceBuilderMethodInvoker.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ServiceBuilderResources;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.ServiceBuilderResources;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.Map;
 
 /**
  * Basic implementation of {@link org.apache.tapestry.ioc.ObjectCreator} that handles invoking a method on the module
  * builder, and figures out the correct parameters to pass into the annotated method.
  */
 public class ServiceBuilderMethodInvoker extends AbstractServiceCreator
@@ -96,4 +96,4 @@
 
         return result;
     }
-}
\ No newline at end of file
+}
@@ -12,17 +12,17 @@
 
 /**
- * Basic implementation of {@link org.apache.tapestry.ioc.ObjectCreator} that handles invoking a method on the module
+ * Basic implementation of {@link org.apache.tapestry5.ioc.ObjectCreator} that handles invoking a method on the module
  * builder, and figures out the correct parameters to pass into the annotated method.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceDecoratorImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/ServiceDecoratorImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================